@@ -4,7 +4,7 @@ Functions dealing with general aspects of all Gnuastro.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2020, Free Software Foundation, Inc.
+Copyright (C) 2016-2021, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -34,12 +34,15 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 /* Configuration macros: */
 
-#define GAL_CONFIG_VERSION                  "0.12"
+#define GAL_CONFIG_VERSION                  "0.14"
 
 #define GAL_CONFIG_HAVE_LIBGIT2             yes
 
-#define GAL_CONFIG_HAVE_FITS_IS_REENTRANT   @HAVE_FITS_IS_REENTRANT@
+#define GAL_CONFIG_HAVE_FITS_IS_REENTRANT   1
 #define GAL_CONFIG_HAVE_WCSLIB_VERSION      1
+#define GAL_CONFIG_HAVE_WCSLIB_DIS_H        1
+#define GAL_CONFIG_HAVE_WCSLIB_MJDREF       0
+#define GAL_CONFIG_HAVE_WCSLIB_OBSFIX       0
 
 #define GAL_CONFIG_HAVE_PTHREAD_BARRIER     1
 
